@@ -7,7 +7,6 @@ import pytest
 from jax import numpy as jnp
 
 import pytreeclass as pytc
-from pytreeclass.src.tree_util import static_value
 
 
 def test_jit_freeze():
@@ -15,7 +14,7 @@ def test_jit_freeze():
     class Linear:
         weight: jnp.ndarray
         bias: jnp.ndarray
-        name: str = field(default=static_value("a"))
+        name: str = pytc.static_field(default=("a"))
 
         def __init__(self, key, in_dim, out_dim):
             self.weight = jax.random.normal(key, shape=(in_dim, out_dim)) * jnp.sqrt(
@@ -64,7 +63,7 @@ def test_jit_freeze():
         model = StackedLinear(
             in_dim=1, out_dim=1, hidden_dim=10, key=jax.random.PRNGKey(0)
         )
-        model.l1 = model.l1.freeze()
+        model = model.at["l1"].freeze()
         for i in range(1, epochs + 1):
             value, model = update(model, x, y)
 
@@ -79,7 +78,7 @@ def test_jit_freeze():
         model = StackedLinear(
             in_dim=1, out_dim=1, hidden_dim=10, key=jax.random.PRNGKey(0)
         )
-        model.l2 = model.l2.freeze()
+        model = model.at["l2"].freeze()
         for i in range(1, epochs + 1):
             value, model = update(model, x, y)
 
@@ -94,7 +93,7 @@ def test_jit_freeze():
         model = StackedLinear(
             in_dim=1, out_dim=1, hidden_dim=10, key=jax.random.PRNGKey(0)
         )
-        model = model.freeze()
+        model = model.at[...].freeze()
         for i in range(1, epochs + 1):
             value, model = update(model, x, y)
 
